from setuptools import setup, find_packages

setup(
    name='phandas',
    version='0.12.0',
    author='Phantom Management',
    author_email='quantbai@gmail.com',
    description='A multi-factor quantitative trading framework for cryptocurrency markets.',
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/quantbai/phandas',
    packages=find_packages(),
    install_requires=[
        'numpy>=2.0.0',
        'pandas>=2.0.0,<3.0.0',
        'matplotlib>=3.7.0',
        'ccxt>=4.0.0',
        'scipy>=1.9.0',
        'python-okx>=0.4.0',
        'requests>=2.25.0',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Financial and Insurance Industry',
        'Intended Audience :: Science/Research',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Office/Business :: Financial',
        'Topic :: Office/Business :: Financial :: Investment',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    python_requires='>=3.8',
)
